window.Gleam.initSearch([{"doc":"testbldr","title":"testbldr","content":"# testbldr\n\n[![Package Version](https://img.shields.io/hexpm/v/testbldr)](https://hex.pm/packages/testbldr)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/testbldr/)\n\nThis library is a dead simple set of utilities for building test suites programatically.\nMost of the time it makes sense to have one test signature per test, and have those tests\nautomatically discovered and run.\nOther times you may want to read test cases in from files, json responses, etc. \nThis library is for the second case.\n\n```gleam\nimport testbldr\nimport testbldr/should\nimport gleam/list\nimport gleam/int\nimport gleam/json\nimport gleam/dynamic\n\npub fn main() {\n\n  // Lets say you have some test\n  // cases in a json file. Here&#39;s an example of building a test suite\n  // from them\n\n  // The function we&#39;re testing\n  let double = fn(x) { x * 2 }\n\n  // Test cases given as json\n  let test_cases =\n    &quot;[\n    {\n        \\&quot;name\\&quot;: \\&quot;1 doubled is 2\\&quot;,\n        \\&quot;input\\&quot;: 1,\n        \\&quot;expected_output\\&quot;: 2\n    },\n    {\n        \\&quot;name\\&quot;: \\&quot;3 doubled is 6\\&quot;,\n        \\&quot;input\\&quot;: 3,\n        \\&quot;expected_output\\&quot;: 6\n    }\n  ]&quot;\n\n  testbldr.demonstrate(\n    that: &quot;Our doubling function works&quot;,\n    with: \n    {\n      // Decode our tests cases from the JSON. If it doesn&#39;t decode\n      // correctly we crash the whole thing because it&#39;s a test suite\n      let assert Ok(test_cases) = test_cases_from_json(test_cases)\n\n      // Map over our tests cases to start transforming them\n      use test_case &lt;- list.map(test_cases)\n\n      // Give each test the name specified in the json, to be printed\n      // properly on test run\n      use &lt;- testbldr.named(test_case.name)\n\n      // The thing we&#39;re actually testing\n      double(test_case.input)\n      |&gt; should.equal(test_case.expected_output)\n    },\n  )\n}\n\n/// Something to parse our JSON test cases into\ntype TestCase {\n  TestCase(name: String, input: Int, expected_output: Int)\n}\n\n/// Decode our list of test cases\nfn test_cases_from_json(\n  input: String,\n) -&gt; Result(List(TestCase), json.DecodeError) {\n  let test_decoder =\n    dynamic.decode3(\n      TestCase,\n      dynamic.field(&quot;name&quot;, of: dynamic.string),\n      dynamic.field(&quot;input&quot;, of: dynamic.int),\n      dynamic.field(&quot;expected_output&quot;, of: dynamic.int),\n    )\n\n  json.decode(from: input, using: dynamic.list(test_decoder))\n}\n```\n","url":"index.html"},{"doc":"testbldr/pieces","title":"Test","content":"pub type Test {\n  Test(name: String, test_function: fn() -&gt; TestOutcome)\n}\n A test has a name and a body (a function which returns a TestOutcome)\nTest(name: String, test_function: fn() -&gt; TestOutcome)\n\n\nSynonyms:\ntestbldr/pieces.Test\ntestbldr/pieces Test","url":"testbldr/pieces.html#Test"},{"doc":"testbldr/pieces","title":"TestOutcome","content":"pub type TestOutcome {\n  Pass\n  Silent\n  Fail(msg: String)\n}\n A test can either pass or fail with a given reason\nPass\n\n\nSilent\n\n\nFail(msg: String)\n\n\nSynonyms:\ntestbldr/pieces.TestOutcome\ntestbldr/pieces TestOutcome","url":"testbldr/pieces.html#TestOutcome"},{"doc":"testbldr/pieces","title":"testbldr/pieces","content":"","url":"testbldr/pieces.html"},{"doc":"testbldr/should","title":"be_error","content":"pub fn be_error(a: Result(a, b)) -&gt; TestOutcome\n\nSynonyms:\ntestbldr/should.be_error\ntestbldr/should be_error","url":"testbldr/should.html#be_error"},{"doc":"testbldr/should","title":"be_false","content":"pub fn be_false(a: Bool) -&gt; TestOutcome\n\nSynonyms:\ntestbldr/should.be_false\ntestbldr/should be_false","url":"testbldr/should.html#be_false"},{"doc":"testbldr/should","title":"be_ok","content":"pub fn be_ok(a: Result(a, b)) -&gt; TestOutcome\n\nSynonyms:\ntestbldr/should.be_ok\ntestbldr/should be_ok","url":"testbldr/should.html#be_ok"},{"doc":"testbldr/should","title":"be_true","content":"pub fn be_true(a: Bool) -&gt; TestOutcome\n\nSynonyms:\ntestbldr/should.be_true\ntestbldr/should be_true","url":"testbldr/should.html#be_true"},{"doc":"testbldr/should","title":"equal","content":"pub fn equal(a: a, b: a) -&gt; TestOutcome\n\nSynonyms:\ntestbldr/should.equal\ntestbldr/should equal","url":"testbldr/should.html#equal"},{"doc":"testbldr/should","title":"not_equal","content":"pub fn not_equal(a: a, b: a) -&gt; TestOutcome\n\nSynonyms:\ntestbldr/should.not_equal\ntestbldr/should not_equal","url":"testbldr/should.html#not_equal"},{"doc":"testbldr/should","title":"testbldr/should","content":"","url":"testbldr/should.html"},{"doc":"testbldr","title":"demonstrate","content":"pub fn demonstrate(\n  with input: List(Test),\n  that name: String,\n) -&gt; Nil\n Run the tests and print the test run output\nSynonyms:\ntestbldr.demonstrate\ntestbldr demonstrate","url":"testbldr.html#demonstrate"},{"doc":"testbldr","title":"named","content":"pub fn named(name: String, new_test: fn() -&gt; TestOutcome) -&gt; Test\n Creates a new test with the given name\nSynonyms:\ntestbldr.named\ntestbldr named","url":"testbldr.html#named"},{"doc":"testbldr","title":"testbldr","content":"","url":"testbldr.html"}]);